@@ -15,6 +15,7 @@
 #  limitations under the License.
 import sys
 from calculate.lib.utils.files import grepFile
+from calculate.lib.utils.tools import cached
 from os import path
 
 _ = lambda x: x
@@ -22,6 +23,37 @@ from calculate.lib.cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
+class X86(object):
+    def __init__(self, rootdn):
+        self.rootdn = rootdn
+        self.usrlib = path.join(rootdn, "usr/lib")
+        self.lib = path.join(rootdn, "lib")
+        self.cusrlib = path.join(rootdn, "usr/lib")
+        self.clib = path.join(rootdn, "lib")
+        self.libmodules = path.join(rootdn, "lib/modules")
+        self.pythonsite = path.join(rootdn, "usr/lib/python2.7/site-packages")
+        self.libopengl = path.join(rootdn, "usr/lib/opengl")
+
+class Amd64(object):
+    def __init__(self, rootdn):
+        self.rootdn = rootdn
+        self.usrlib = path.join(rootdn, "usr/lib64")
+        self.lib = path.join(rootdn, "lib64")
+        self.cusrlib = path.join(rootdn, "usr/lib")
+        self.clib = path.join(rootdn, "lib")
+        self.libmodules = path.join(rootdn, "lib/modules")
+        self.pythonsite = path.join(rootdn, "usr/lib64/python2.7/site-packages")
+        self.libopengl = path.join(rootdn, "usr/lib64/opengl")
+
+@cached(each_instance=True)
+def SystemPath(rootdn):
+    lib64path = path.join(rootdn, "lib64")
+    libpath = path.join(rootdn, "lib")
+    if path.exists(lib64path):
+        return Amd64(rootdn)
+    else:
+        return X86(rootdn)
+
 
 class SystemType(object):
     """
